==> u_team_core-fabric-1.20.1-5.1.4.382-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/screen/ButtonTestScreenVanilla.java <==
package info.u_team.u_team_test.test_multiloader.screen;

import org.slf4j.Logger;

import com.mojang.logging.LogUtils;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_342;
import net.minecraft.class_344;
import net.minecraft.class_3532;
import net.minecraft.class_357;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_7529;
import net.minecraft.class_7919;
import net.minecraft.class_8084;

public class ButtonTestScreenVanilla extends class_437 {
	
	private static final Logger LOGGER = LogUtils.getLogger();
	
	private int sliderValue = 0;
	
	public ButtonTestScreenVanilla() {
		super(class_2561.method_43470("test"));
	}
	
	@Override
	protected void method_25426() {
		method_37063(new class_4185.class_7840(class_2561.method_43470("Test Button"), button -> {
			LOGGER.info("Clicked Testbutton");
		}).method_46434(50, 50, 200, 20).method_46436(class_7919.method_47407(class_2561.method_43470("Tooltip for Test Button"))).method_46431());
		
		method_37063(new class_344(50, 80, 50, 20, 0, 106, 20, class_339.field_22757, 256, 256, button -> {
			LOGGER.info("Clicked Test ImageButton");
		}, class_2561.method_43470("Test ImageButton")));
		
		final class_339 textImageButton = method_37063(class_8084.method_48601(class_2561.method_43470("Test Button with Image"), class_339.field_22757, button -> {
			LOGGER.info("Clicked Testbutton with Image");
		}).method_48605(3, 109).method_48606(65, 3).method_48604(20).method_48607(14, 14).method_48608(256, 256).method_48603());
		textImageButton.method_48229(50, 110);
		textImageButton.method_47400(class_7919.method_47407(class_2561.method_43470("Tooltip for Test Button with Image")));
		
		final class_339 editBox = method_37063(new class_342(field_22793, 50, 140, 200, 20, class_2561.method_43470("Test box")));
		editBox.method_47400(class_7919.method_47407(class_2561.method_43470("Test text box")));
		
		final class_339 multiEditBox = method_37063(new class_7529(field_22793, 50, 170, 200, 20, class_2561.method_43473(), class_2561.method_43470("Test box")));
		multiEditBox.method_47400(class_7919.method_47407(class_2561.method_43470("Test multi line text box")));
		
		method_37063(new class_357(50, 200, 200, 20, class_2561.method_43473(), 0) {
			
			{
				method_25346();
			}
			
			@Override
			protected void method_25346() {
				method_25355(class_2561.method_43470("Slider Test " + sliderValue));
			}
			
			@Override
			protected void method_25344() {
				sliderValue = class_3532.method_15357(class_3532.method_15390(0, 50, field_22753));
				LOGGER.info("Update slider value to {}", sliderValue);
			}
		});
	}
	
	@Override
	public void method_25394(class_332 guiGrapics, int mouseX, int mouseY, float partialTick) {
		method_25420(guiGrapics);
		super.method_25394(guiGrapics, mouseX, mouseY, partialTick);
	}
	
}

==> u_team_core-fabric-1.21.1-5.6.2.364-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/screen/ButtonTestScreenVanilla.java <==
package info.u_team.u_team_test.test_multiloader.screen;

import org.slf4j.Logger;

import com.mojang.logging.LogUtils;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_339;
import net.minecraft.class_342;
import net.minecraft.class_344;
import net.minecraft.class_3532;
import net.minecraft.class_357;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_7529;
import net.minecraft.class_7919;
import net.minecraft.class_8666;

public class ButtonTestScreenVanilla extends class_437 {
	
	private static final Logger LOGGER = LogUtils.getLogger();
	
	private int sliderValue = 0;
	
	public ButtonTestScreenVanilla() {
		super(class_2561.method_43470("test"));
	}
	
	@Override
	protected void method_25426() {
		method_37063(new class_4185.class_7840(class_2561.method_43470("Test Button"), button -> {
			LOGGER.info("Clicked Testbutton");
		}).method_46434(50, 50, 200, 20).method_46436(class_7919.method_47407(class_2561.method_43470("Tooltip for Test Button"))).method_46431());
		
		method_37063(new class_344(50, 80, 50, 20, new class_8666(class_2960.method_60656("backup/changes"), class_2960.method_60656("backup/changes_highlighted")), button -> {
			LOGGER.info("Clicked Test ImageButton");
		}, class_2561.method_43470("Test ImageButton")));
		
		final class_339 textImageButton = method_37063(class_4185.method_46430(class_2561.method_43470("Test Button with Image"), button -> {
			LOGGER.info("Clicked Testbutton with Image");
		}).method_46431());
		textImageButton.method_48229(50, 110);
		textImageButton.method_47400(class_7919.method_47407(class_2561.method_43470("Tooltip for Test Button with Image")));
		
		final class_339 editBox = method_37063(new class_342(field_22793, 50, 140, 200, 20, class_2561.method_43470("Test box")));
		editBox.method_47400(class_7919.method_47407(class_2561.method_43470("Test text box")));
		
		final class_339 multiEditBox = method_37063(new class_7529(field_22793, 50, 170, 200, 20, class_2561.method_43473(), class_2561.method_43470("Test box")));
		multiEditBox.method_47400(class_7919.method_47407(class_2561.method_43470("Test multi line text box")));
		
		method_37063(new class_357(50, 200, 200, 20, class_2561.method_43473(), 0) {
			
			{
				method_25346();
			}
			
			@Override
			protected void method_25346() {
				method_25355(class_2561.method_43470("Slider Test " + sliderValue));
			}
			
			@Override
			protected void method_25344() {
				sliderValue = class_3532.method_15357(class_3532.method_15390(0, 50, field_22753));
				LOGGER.info("Update slider value to {}", sliderValue);
			}
		});
	}
}
